from beehiiv.endpoint import Endpoint


class Subscriptions(Endpoint):

    def __init__(self, api_key, publicationId):
        super().__init__(api_key)
        self.endpoint = "/publications/{}/subscriptions"
        self.publicationId = publicationId

    def create(self, email, reactivate_existing=None, send_welcome_email=None,
               utm_source=None, utm_medium=None, utm_campaign=None,
               referring_site=None, referral_code=None, custom_fields=[]):
        '''create'''
        return self._make_call(
            [self.publicationId],
            data={
                "email": email,
                "reactivate_existing": reactivate_existing,
                "send_welcome_email": send_welcome_email,
                "utm_source": utm_source,
                "utm_medium": utm_medium,
                "utm_campaign": utm_campaign,
                "referring_site": referring_site,
                "referral_code": referral_code,
                "custom_fields": custom_fields,
            },
            method="POST",
        ).json()

    def index(self, email=None, expand=[], limit=None, page=None, status=None,
              tier=None):
        '''index'''
        return self._make_call(
            [self.publicationId],
            params={
                "email": email,
                "expand[]": expand,
                "limit": limit,
                "page": page,
                "status": status,
                "tier": tier,
            },
        ).json()

    def show(self, subscriptionId, expand=[]):
        '''show'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            params={
                "expand[]": expand,
            },
        ).json()

    def update(self, subscriptionId, unsubscribe=None, custom_fields=[]):
        '''update'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            data={
                "unsubscribe": unsubscribe,
                "custom_fields": custom_fields,
            },
            method="PUT",
        ).json()

    def delete(self, subscriptionId):
        '''delete'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            method="DELETE",
        ).json()



from beehiiv.endpoint import Endpoint


class Segments(Endpoint):

    def __init__(self, api_key, publicationId):
        super().__init__(api_key)
        self.endpoint = "/publications/{}/segments"
        self.publicationId = publicationId

    def index(self, limit=None, page=None, status=None, type=None):
        '''index'''
        return self._make_call(
            [self.publicationId],
            params={
                "limit": limit,
                "page": page,
                "status": status,
                "type": type,
            },
        ).json()

    def show(self, segmentId):
        '''show'''
        return self._make_call(
            [self.publicationId, segmentId],
            endpoint=self.endpoint + "/{}",
        ).json()

    def delete(self, segmentId):
        '''delete'''
        return self._make_call(
            [self.publicationId, segmentId],
            endpoint=self.endpoint + "/{}",
            method="DELETE",
        ).json()

    def expand_results(self, segmentId, limit=None, page=None):
        '''expand results'''
        return self._make_call(
            [self.publicationId, segmentId],
            endpoint=self.endpoint + "/{}/results",
            params={
                "limit": limit,
                "page": page,
            },
        ).json()



from beehiiv.endpoint import Endpoint


class ReferralProgram(Endpoint):

    def __init__(self, api_key, publicationId):
        super().__init__(api_key)
        self.endpoint = "/publications/{}/referral_program"
        self.publicationId = publicationId

    def show(self, emailBlastId, limit=None, page=None):
        '''show'''
        return self._make_call(
            [self.publicationId, emailBlastId],
            params={
                "limit": limit,
                "page": page,
            },
        ).json()



from beehiiv.endpoint import Endpoint


class EmailBlasts(Endpoint):

    def __init__(self, api_key, publicationId):
        super().__init__(api_key)
        self.endpoint = "/publications/{}/email_blasts"
        self.publicationId = publicationId

    def index(self, expand=[], limit=None, page=None):
        '''index'''
        return self._make_call(
            [self.publicationId],
            params={
                "expand[]": expand,
                "limit": limit,
                "page": page,
            },
        ).json()

    def show(self, emailBlastId, expand=[]):
        '''show'''
        return self._make_call(
            [self.publicationId, emailBlastId],
            endpoint=self.endpoint + "/{}",
            params={
                "expand[]": expand,
            },
        ).json()

    def update(self, subscriptionId, unsubscribe=None, custom_fields=[]):
        '''update'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            data={
                "unsubscribe": unsubscribe,
                "custom_fields": custom_fields,
            },
            method="PUT",
        ).json()

    def delete(self, subscriptionId):
        '''delete'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            method="DELETE",
        ).json()



from beehiiv.endpoint import Endpoint


class Publications(Endpoint):

    def __init__(self, api_key):
        super().__init__(api_key)
        self.endpoint = "/publications"

    def index(self, expand=[], limit=None, page=None):
        '''index'''
        return self._make_call(
            None,
            params={
                "expand[]": expand,
                "limit": limit,
                "page": page,
            },
        ).json()

    def show(self, publicationId, expand=[]):
        '''show'''
        return self._make_call(
            [publicationId],
            endpoint=self.endpoint + "/{}",
            params={
                "expand[]": expand,
            },
        ).json()



from beehiiv.email_blasts import EmailBlasts
from beehiiv.posts import Posts
from beehiiv.publications import Publications
from beehiiv.referral_program import ReferralProgram
from beehiiv.segments import Segments
from beehiiv.subscriptions import Subscriptions

class BeeHiiv:

    def __init__(self, api_key, publicationId=None):
        '''init'''
        self.email_blasts = EmailBlasts(api_key, publicationId)
        self.posts = Posts(api_key, publicationId)
        self.publications = Publications(api_key)
        self.referral_program = ReferralProgram(api_key, publicationId)
        self.segments = Segments(api_key, publicationId)
        self.subscriptions = Subscriptions(api_key, publicationId)




import inspect
import requests

class Endpoint:
    api_uri = "https://api.beehiiv.com/v2"
    endpoint = None

    def __init__(self, api_key):
        '''init'''
        self.api_key = api_key

    def _craft_url(self, endpoint, params):
        '''make api url'''
        return "{}{}".format(
            self.api_uri,
            endpoint.format(*params) if params else endpoint,
        )

    def _create_call_headers(self):
        '''create headers'''
        return {
            "Authorization": "Bearer {}".format(self.api_key),
        }

    def _make_call(self, endpoint_params, params=None, endpoint=None, data=None,
                   method="GET"):
        '''make call api'''
        return requests.request(
            method,
            headers=self._create_call_headers(),
            url=self._craft_url(
                self.endpoint if not endpoint else endpoint,
                endpoint_params
            ),
            data=data,
            params=params,
        )




from setuptools import setup

from beehiiv.__version__ import __version__

with open('README.md', 'r',) as f:
    readme = f.read()

setup(
    name='beehiiv',
    version=__version__,
    install_requires=['requests'],
    packages=['beehiiv'],
    url='https://github.com/abrihter/beehiiv',
    long_description_content_type="text/markdown",
    long_description=readme,
    license='MIT',
    author='abrihter',
    author_email='',
    description='Python wrapper for the BeeHiiv API',
    keywords=['BEEHIIV', 'API', 'WRAPPER'],
    download_url='https://github.com/abrihter/beehiiv/archive/refs/tags/v0.1b.tar.gz',  # noqa E501
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)



from beehiiv.endpoint import Endpoint


class Posts(Endpoint):

    def __init__(self, api_key, publicationId):
        super().__init__(api_key)
        self.endpoint = "/publications/{}/posts"
        self.publicationId = publicationId

    def index(self, audience=None, content_tags=[], expand=[], limit=None,
              page=None, platform=None, status=None):
        '''index'''
        return self._make_call(
            [self.publicationId],
            params={
                "audience": audience,
                "content_tags[]": content_tags,
                "expand[]": expand,
                "limit": limit,
                "page": page,
                "platform": platform,
                "status": status,
            },
        ).json()

    def show(self, postId, expand=[]):
        '''show'''
        return self._make_call(
            [self.publicationId, postId],
            endpoint=self.endpoint + "/{}",
            params={
                "expand[]": expand,
            },
        ).json()

    def destory(self, subscriptionId, postId):
        '''delete'''
        return self._make_call(
            [self.publicationId, subscriptionId],
            endpoint=self.endpoint + "/{}",
            method="DELETE",
        ).json()
